@@ -284,6 +284,9 @@ class SensorGraphPlugin(TileBusProxyPlugin):
             if config_desc.name == ignoreconfigs_list_var:
                 ignoreconfigs_bytes = config_desc.data
 
+        # Sort config list first by slot, then variable number
+        config_list = sorted(config_list, key=lambda x: (str(x.target), x.name))
+
         ignore_list = _parse_ignoreconfigs(ignoreconfigs_bytes)
         for config in config_list:
             if _is_ignored_config(ignore_list, str(config.target), config.name):
